@@ -1,5 +1,5 @@
 #  Cflow.pm - perl module for processing raw flow files
-#  Copyright (C) 1998-2001  Dave Plonka
+#  Copyright (C) 1998-2002  Dave Plonka
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-# $Id: Cflow.pm,v 1.40 2001/06/15 19:07:09 dplonka Exp $
+# $Id: Cflow.pm,v 1.51 2002/01/31 01:07:19 dplonka Exp $
 # Dave Plonka <plonka@doit.wisc.edu>
 
 use strict;
@@ -34,7 +34,7 @@ my %bits = (
    RST => $Cflow::TH_RST,
    PUSH => $Cflow::TH_PUSH,
    ACK => $Cflow::TH_ACK,
-   URG => $Cflow::TH_URH
+   URG => $Cflow::TH_URG
 );
 
 # got these from "netinet/ip_icmp.ph" (from "h2ph netinet/ip_icmp.h")
@@ -170,7 +170,11 @@ sub TIESCALAR {
 sub FETCH {
    my $this = shift;
    return '' unless (1 == $Cflow::protocol);
-   return $typecode[$Cflow::ICMPType]->[1]->[$Cflow::ICMPCode] . $typecode[$Cflow::ICMPType]->[0]
+   return '' unless defined $typecode[$Cflow::ICMPType]->[0];
+   return $typecode[$Cflow::ICMPType]->[0]
+      unless defined $typecode[$Cflow::ICMPType]->[1]->[$Cflow::ICMPCode];
+   return $typecode[$Cflow::ICMPType]->[1]->[$Cflow::ICMPCode]
+      . $typecode[$Cflow::ICMPType]->[0]
 }
 
 package Cflow::InetNtoA; #######################################################
@@ -181,12 +185,12 @@ sub TIESCALAR {
    die unless $class;
    my $this = shift;
    die unless ref($this);
-   bless $this, $class
+   bless \$this, $class
 }
 
 sub FETCH {
    my $this = shift;
-   join('.', unpack('C4', pack('N', $$this))) # inet_ntoa was too slow
+   join('.', unpack('C4', pack('N', $$$this))) # inet_ntoa was too slow
 }
 
 sub STORE {
@@ -292,7 +296,7 @@ sub STORE {
 package Cflow; #################################################################
 
 # convert the RCS revision to a reasonable Exporter VERSION:
-'$Revision: 1.40 $' =~ m/(\d+)\.(\d+)/ && (( $Cflow::VERSION ) = sprintf("%d.%03d", $1, $2));
+'$Revision: 1.51 $' =~ m/(\d+)\.(\d+)/ && (( $Cflow::VERSION ) = sprintf("%d.%03d", $1, $2));
 
 require Exporter;
 require DynaLoader;
@@ -433,17 +437,24 @@ It was originally conceived and written for use by FlowScan:
 
    http://net.doit.wisc.edu/~plonka/FlowScan/
 
-=head1 Collectors
+=head1 Flow File Sources
 
-This package is of little use except to read raw flow files produced by
-another software package which collects flow information from IP
-routers.  The following collectors are supported:
+This package is of little use on its own.  It requires input in the
+form of time-stamped raw flow files produced by other software
+packages.  These "flow sources" either snoop a local ethernet (via
+libpcap) or collect flow information from IP routers that are
+configured to export said information.  The following flow sources are
+supported:
 
 =over 4
 
-=item OSU flow-tools by Mark Fullmer (with NetFlow v1, v5, v6, or v7):
+=item argus by Carter Bullard:
 
-   ftp://ftp.net.ohio-state.edu/users/maf/cisco/
+   http://www.qosient.com/argus/
+
+=item flow-tools by Mark Fullmer (with NetFlow v1, v5, v6, or v7):
+
+   http://www.splintered.net/sw/flow-tools/
 
 =item CAIDA's cflowd (with NetFlow v5):
 
@@ -571,7 +582,7 @@ secs since epoch at start of flow
 
 fractional portion of startime (in milliseconds)
 
-This will be zero unless used with OSU flow-tools.
+This will be zero unless the source is flow-tools or argus.
 
 =item $Cflow::endtime
 
@@ -581,7 +592,7 @@ secs since epoch at last packet of flow
 
 fractional portion of endtime (in milliseconds)
 
-This will be zero unless used with OSU flow-tools.
+This will be zero unless the source is flow-tools or argus.
 
 =item $Cflow::protocol
 
@@ -796,11 +807,55 @@ Cflow::find():
 
    Cflow::find(sub { wanted(@params) }, @files);
 
+=head1 ARGUS NOTES
+
+Argus uses a bidirectional flow model.  This means that some argus
+flows represent packets not only in the forward direction (from
+"source" to "destination"), but also in the reverse direction (from the
+so-called "destination" to the "source").  However, this module uses a
+unidirection flow model, and therfore splits some argus flows into two
+unidirectional flows for the purpose of reporting.
+
+Currently, using this module's API there is no way to determine if two
+subsequently reported unidirectional flows were really a single argus
+flow.  This may be addressed in a future release of this package.
+
+Furthermore, for argus flows which represent bidirectional ICMP
+traffic, this module presumes that all the reverse packets were
+ECHOREPLYs (sic).  This is sometimes incorrect as described here:
+
+   http://www.theorygroup.com/Archive/Argus/2002/msg00016.html
+
+and will be fixed in a future release of this package.
+
+Timestamps ($startime and $endtime) are sometimes reported incorrectly
+for bidirectional argus flows that represent only one packet in each
+direction.  This will be fixed in a future release.
+
+Argus flows sometimes contain information which does not map directly
+to the flow variables presented by this module.  For the time being,
+this information is simply not accessible through this module's API.
+This may be addressed in a future release.
+
+Lastly, argus flows produced from observed traffic on a local ethernet
+do not contain enough information to meaningfully set the values of all
+this module's flow variables.  For instance, the next-hop and
+input/output ifIndex numbers are missing.  For the time being, all
+argus flows accessed throught this module's API will have both the
+$input_if and $output_if as 42.  Althought 42 is the answer to life,
+the universe, and everthing, in this context, it is just an arbitrary
+number.  It is important that $output_if is non-zero, however, since
+existing FlowScan reports interpret an $output_if value of zero to mean
+that the traffic represented by that flow was not forwarded (i.e.
+dropped).  For similar reasons, the $nexthopip for all argus flows is
+reported as "127.0.0.1".
+
 =head1 BUGS
 
-Currently, only NetFlow version 5 is supported with cflowd. 
+Currently, only NetFlow version 5 is supported when reading
+cflowd-format raw flow files.
 
-When built with support for OSU flow-tools and attempting to read
+When built with support for flow-tools and attempting to read
 a cflowd format raw flow file from standard input, you'll get the
 error:
 
@@ -809,21 +864,31 @@ error:
 For the time being, the workaround is to write the content to a file
 and read it from directly from there rather than from standard input.
 (This happens because we can't close and re-open file descriptor zero
-after determining that the content was not in OSU flow-tools format.)
+after determining that the content was not in flow-tools format.)
 
-When built with support for OSU flow-tools and using verbose mode,
+When built with support for flow-tools and using verbose mode,
 Cflow::find will generate warnings if you process a cflowd format raw
 flow file.  This happens because it will first attempt to open the file
 as a flow-tools format raw flow file (which will produce a warning
 message), and then revert to handling it as cflowd format raw flow
 file.
 
+Likewise, when built with support for argus and attempting to read a
+cflowd format raw flow file from standard input, you'll get this
+warning message:
+
+   not Argus-2.0 data stream.
+
+This is because argus (as of argus-2.0.4) doesn't seem to have a mode
+in which such warning messages are supressed.
+
 The $Cflow::raw flow variable contains the flow record in cflowd
-format, even if it was read from a raw flow file produced by OSU
-flow-tools.  Because cflowd discards the fractional portion of the flow
+format, even if it was read from a raw flow file produced by flow-tools
+or argus.  Because cflowd discards the fractional portion of the flow
 start and end time, only the whole seconds portion of these times will
 be retained.  (That is, the raw record in $Cflow::raw does not contain
-the $start_msecs and $end_msecs.)
+the $start_msecs and $end_msecs, so using $Cflow::raw to convert to
+cflowd format is a lossy operation.)
 
 When used with cflowd, Cflow::find() will generate warnings if the flow
 data file is "invalid" as far as its concerned.  To avoid this, you
@@ -843,7 +908,7 @@ File::Find.
 
 Dave Plonka <plonka@doit.wisc.edu>
 
-Copyright (C) 1998-2001  Dave Plonka.
+Copyright (C) 1998-2002  Dave Plonka.
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
 Free Software Foundation; either version 2 of the License, or (at your
@@ -851,7 +916,7 @@ option) any later version.
 
 =head1 VERSION
 
-The version number is the module file RCS revision number (B<$Revision: 1.40 $>)
+The version number is the module file RCS revision number (B<$Revision: 1.51 $>)
 with the minor number printed right justified with leading zeroes to 3
 decimal places.  For instance, RCS revision 1.1 would yield a package
 version number of 1.001.
