@@ -23,4 +23,6 @@
 /* DEC */
 #undef HAVE_LL_STRTOUL
 
+/* OPENSSL */
+#undef HAVE_OPENSSL
 
