@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: fmt.c,v 1.16 2003/02/13 02:38:41 maf Exp $
+ *      $Id: fmt.c,v 1.17 2003/03/06 22:57:25 maf Exp $
  */
 
 #include "ftconfig.h"
@@ -79,15 +79,14 @@ unsigned int fmt_uint16s(struct ftsym *ftsym, int max, char *s, u_int16 u,
   if (ftsym && ftsym_findbyval(ftsym, (u_int32)u, &str) == 1) {
 
     strncpy(s, str, max);
+    s[max-1] = 0;
 
-    ret = strlen(str);
+    ret = strlen(s);
 
     if (format == FMT_PAD_RIGHT)
-      for (; ret < max; ++ret)
+      for (; ret < (max-1); ++ret)
         s[ret] = ' ';
 
-    s[max-1] = 0;
-
     if (format == FMT_PAD_RIGHT)
       return max-1;
     else
@@ -108,15 +107,14 @@ unsigned int fmt_uint8s(struct ftsym *ftsym, int max, char *s, u_int8 u,
   if (ftsym && ftsym_findbyval(ftsym, (u_int32)u, &str) == 1) {
 
     strncpy(s, str, max);
+    s[max-1] = 0;
 
-    ret = strlen(str);
+    ret = strlen(s);
 
     if (format == FMT_PAD_RIGHT)
-      for (; ret < max; ++ret)
+      for (; ret < (max-1); ++ret)
         s[ret] = ' ';
 
-    s[max-1] = 0;
-
     if (format == FMT_PAD_RIGHT)
       return max-1;
     else
@@ -137,15 +135,14 @@ unsigned int fmt_uint32s(struct ftsym *ftsym, int max, char *s, u_int32 u,
   if (ftsym && ftsym_findbyval(ftsym, (u_int32)u, &str) == 1) {
 
     strncpy(s, str, max);
+    s[max-1] = 0;
 
-    ret = strlen(str);
+    ret = strlen(s);
 
     if (format == FMT_PAD_RIGHT)
-      for (; ret < max; ++ret)
+      for (; ret < (max-1); ++ret)
         s[ret] = ' ';
 
-    s[max-1] = 0;
-
     if (format == FMT_PAD_RIGHT)
       return max-1;
     else
