@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: ftchash.c,v 1.13 2003/02/13 02:38:41 maf Exp $
+ *      $Id: ftchash.c,v 1.14 2003/08/12 18:04:25 maf Exp $
  */
 
 #include "ftconfig.h"
@@ -359,6 +359,10 @@ int ftchash_sort(struct ftchash *ftch, int offset, int flags)
   void *rec;
   u_int64 x;
 
+  /* entries to sort? */
+  if (!ftch->entries)
+    return 0;
+
   /* free memory from previous call */
   if (ftch->sorted_recs)
     free(ftch->sorted_recs);
