@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: ftdecode.c,v 1.24 2003/02/13 02:38:41 maf Exp $
+ *      $Id: ftdecode.c,v 1.25 2005/05/10 15:45:47 maf Exp $
  */
 
 #include "ftconfig.h"
@@ -706,7 +706,7 @@ int fts3rec_pdu_v5_decode(struct ftpdu *ftpdu)
     rec_v5->sysUpTime = ph->sysUpTime;
 
     rec_v5->engine_type = pdu_v5->engine_type;
-    rec_v5->engine_type = pdu_v5->engine_id;
+    rec_v5->engine_id = pdu_v5->engine_id;
 
 
     rec_v5->srcaddr = pdu_v5->records[n].srcaddr;
