@@ -23,38 +23,38 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: ftfile.c,v 1.16 2001/04/24 21:07:18 maf Exp $
+ *      $Id: ftfile.c,v 1.24 2003/02/13 02:38:42 maf Exp $
  */
 
-#if HAVE_CONFIG_H
- #include <config.h>
-#endif
+#include "ftconfig.h"
+#include "ftlib.h"
 
-#include <sys/errno.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/uio.h>
 #include <sys/resource.h>
-#include <dirent.h>
 #include <sys/stat.h>
+#include <dirent.h>
+#include <errno.h>
 #include <syslog.h>
 #include <limits.h>
 #include <unistd.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <time.h>
+#include <fcntl.h>
+
 #if HAVE_STRINGS_H
  #include <strings.h>
 #endif
 #if HAVE_STRING_H
   #include <string.h>
 #endif
-#include <time.h>
-#include <fcntl.h>
-#include "ftlib.h"
-#include "support.h"
 
 int load_dir(char *prefix, struct ftfile_entries *fte, int flags, int *depth);
 
+extern int debug;
+
 /*
  * function: ftfile_entry_new
  * 
@@ -67,6 +67,8 @@ struct ftfile_entry *ftfile_entry_new(int len)
   if (!(e = (struct ftfile_entry*)malloc(sizeof (struct ftfile_entry))))
     return (struct ftfile_entry*)0L;
 
+  bzero(e, sizeof *e);
+
   if (!(e->name = (char*)malloc(len+1))) {
     free (e);
     return (struct ftfile_entry*)0L;
@@ -137,7 +139,7 @@ int ftfile_loadfile(struct ftfile_entries *fte, char *fname, int flags)
     }
 
     if (ftiheader_read(fd, &head) < 0) {
-      fterr_warnx("ftiheader_read(): failed");
+      fterr_warnx("ftiheader_read(%s): Failed, ignoring file.", fname);
       close(fd);
       return 0;
     }
@@ -212,7 +214,6 @@ int ftfile_loadfile(struct ftfile_entries *fte, char *fname, int flags)
  */
 int ftfile_loaddir(struct ftfile_entries *fte, char *dir, int flags)
 {
-  extern int debug;
   int depth, here;
   DIR *dirp;
 
@@ -309,7 +310,6 @@ int ftfile_add_tail(struct ftfile_entries *fte, char *fname, off_t size,
 */
 int ftfile_expire (struct ftfile_entries *fte, int doit, int curbytes)
 {
-  extern int debug;
   u_int i;
   struct ftfile_entry *n1;
   u_int64 bytes;
@@ -410,7 +410,7 @@ int ftfile_dump(struct ftfile_entries *fte)
  * 
  */
 void ftfile_pathname(char *buf, int bsize, int nest, struct ftver ftv,
- int done, u_int32 time)
+ int done, u_int32 ftime)
 {
   struct tm *tm;
   char *prefix, dbuf[64];
@@ -418,11 +418,11 @@ void ftfile_pathname(char *buf, int bsize, int nest, struct ftver ftv,
   char gmt_sign;
   int tm_gmtoff;
   
-  if (!(tm = localtime ((time_t*)&time))) {
+  if (!(tm = localtime ((time_t*)&ftime))) {
     snprintf(buf, bsize, ".");
   }
 
-  tm_gmtoff = get_gmtoff(time);
+  tm_gmtoff = get_gmtoff(ftime);
 
   /* compute GMT offset */
   if (tm_gmtoff >= 0) {
@@ -449,12 +449,10 @@ void ftfile_pathname(char *buf, int bsize, int nest, struct ftver ftv,
   } else if (nest == -2) {
     sprintf(dbuf, "%2.2d-%2.2d/%2.2d-%2.2d-%2.2d/",
       (int)tm->tm_year+1900, (int)tm->tm_mon+1,
-      (int)tm->tm_year+1900, (int)tm->tm_mon+1, (int)tm->tm_mon+1);
+      (int)tm->tm_year+1900, (int)tm->tm_mon+1, (int)tm->tm_mday);
   } else if (nest == -1) {
-    sprintf(dbuf, "%2.2d/%2.2d-%2.2d/%2.2d-%2.2d-%2.2d/",
-      (int)tm->tm_year+1900,
-      (int)tm->tm_year+1900, (int)tm->tm_mon+1,
-      (int)tm->tm_year+1900, (int)tm->tm_mon+1, (int)tm->tm_mon+1);
+    sprintf(dbuf, "%2.2d-%2.2d-%2.2d/",
+      (int)tm->tm_year+1900, (int)tm->tm_mon+1, (int)tm->tm_mday);
   } else { /* really an error */
     dbuf[0] = 0;
   }
@@ -490,20 +488,19 @@ void ftfile_pathname(char *buf, int bsize, int nest, struct ftver ftv,
  * Create directory components for pathname.
  *
  * nest controls depth
- * -3    YY/YY-MM/YY-MM-DD
- * -2    YY-MM/YY-MM-DD
- * -1    YY-MM-DD
+ * -3    YYYY/YYYY-MM/YYYY-MM-DD
+ * -2    YYYY-MM/YYYY-MM-DD
+ * -1    YYYY-MM-DD
  *  0    no directories are created
- *  1    YY
- *  2    YY/YY-MM
- *  3    YY/YY-MM/YY-MM-DD
+ *  1    YYYY
+ *  2    YYYY/YYYY-MM
+ *  3    YYYY/YYYY-MM/YYYY-MM-DD
  *
  * returns -1 on error
  * 
  */
-int ftfile_mkpath(u_int32 time, int nest)
+int ftfile_mkpath(u_int32 ftime, int nest)
 {
-  extern int errno;
   struct tm *tm;
   char buf[32];
 
@@ -515,18 +512,18 @@ int ftfile_mkpath(u_int32 time, int nest)
   if ((nest > 3) || (nest < -3))
     return -1;
 
-  if (!(tm = localtime ((time_t*)&time)))
+  if (!(tm = localtime ((time_t*)&ftime)))
     return -1;
 
   if (nest == -1)
-    /* YY-MM-DD */
+    /* YYYY-MM-DD */
     sprintf(buf, "%2.2d-%2.2d-%2.2d", 
       (int)tm->tm_year+1900, (int)tm->tm_mon+1, (int)tm->tm_mday);
   else if (nest == -2)
-    /* YY-MM */
+    /* YYYY-MM */
     sprintf(buf, "%2.2d-%2.2d", (int)tm->tm_year+1900, (int)tm->tm_mon+1);
   else if ((nest == -3) || (nest > 0))
-    /* YY */
+    /* YYYY */
     sprintf(buf, "%2.2d", (int)tm->tm_year+1900);
   else 
     /* not reached */
@@ -543,12 +540,12 @@ int ftfile_mkpath(u_int32 time, int nest)
     return 0;
 
   if (nest == -2)
-    /* YY-MM/YY-MM-DD */
+    /* YYYY-MM/YYYY-MM-DD */
     sprintf(buf, "%2.2d-%2.2d/%2.2d-%2.2d-%2.2d",
       (int)tm->tm_year+1900, (int)tm->tm_mon+1,
       (int)tm->tm_year+1900, (int)tm->tm_mon+1, (int)tm->tm_mday);
   else if ((nest == -3) || (nest > 0))
-    /* YY/YY-MM */
+    /* YYYY/YYYY-MM */
     sprintf(buf, "%2.2d/%2.2d-%2.2d", (int)tm->tm_year+1900,
       (int)tm->tm_year+1900, (int)tm->tm_mon+1);
   else
@@ -566,7 +563,7 @@ int ftfile_mkpath(u_int32 time, int nest)
     return 0;
 
   if ((nest == 3) || (nest == -3))
-    /* YY/YY-MM/YY-MM-DD */
+    /* YYYY/YYYY-MM/YYYY-MM-DD */
     sprintf(buf, "%2.2d/%2.2d-%2.2d/%2.2d-%2.2d-%2.2d", (int)tm->tm_year+1900,
       (int)tm->tm_year+1900, (int)tm->tm_mon+1, (int)tm->tm_year+1900,
       (int)tm->tm_mon+1, (int)tm->tm_mday);
@@ -693,7 +690,7 @@ int load_dir(char *prefix, struct ftfile_entries *fte, int flags, int *depth)
       }
 
       if (ftiheader_read(fd, &head) < 0) {
-        fterr_warnx("ftiheader_read(): failed");
+        fterr_warnx("ftiheader_read(%s): Failed, ignoring file.", dirent->d_name);
         close(fd);
         continue;
       }
