@@ -23,12 +23,11 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: ftio.c,v 1.29 2001/07/06 14:26:59 maf Exp $
+ *      $Id: ftio.c,v 1.47 2003/02/24 00:51:47 maf Exp $
  */
 
-#if HAVE_CONFIG_H
- #include <config.h>
-#endif
+#include "ftconfig.h"
+#include "ftlib.h"
 
 #include <sys/time.h>
 #include <sys/types.h>
@@ -44,17 +43,24 @@
 #include <unistd.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <time.h>
+#include <fcntl.h>
+#include <zlib.h>
+
 #if HAVE_STRINGS_H
  #include <strings.h>
 #endif
 #if HAVE_STRING_H
   #include <string.h>
 #endif
-#include <time.h>
-#include <fcntl.h>
-#include <zlib.h>
-#include "ftlib.h"
-#include "fmt.h"
+
+#if HAVE_MMAP
+ #include <sys/types.h>
+ #include <sys/mman.h>
+ #include <sys/stat.h>
+#endif
+
+int readn(register int fd, register void *ptr, register int nbytes);
 
 /*
  * function: ftio_init
@@ -84,6 +90,7 @@ int ftio_init(struct ftio *ftio, int fd, int flag)
 {
   int i, ret;
   struct stat sb;
+  struct ftver ftv;
 
   bzero(ftio, sizeof (struct ftio));
 
@@ -150,7 +157,13 @@ int ftio_init(struct ftio *ftio, int fd, int flag)
   
     /* calculate record size */
     if ((ftio->rec_size = ftio_rec_size(ftio)) < 0) {
-      fterr_warnx("Unsupported record type");
+      fterr_warnx("Unsupported record type (ftio_rec_size_");
+      goto ftio_init_out;
+    }
+
+    /* calculate FT_XFIELD* */
+    if ((ftio->xfield = ftio_xfield(ftio)) == -1) {
+      fterr_warnx("Unsupported record type (ftio_xfield)");
       goto ftio_init_out;
     }
   
@@ -159,6 +172,10 @@ int ftio_init(struct ftio *ftio, int fd, int flag)
       goto ftio_init_out;
     }
 
+    /* get byte for fields */
+    ftio_get_ver(ftio, &ftv);
+    fts3rec_compute_offsets(&ftio->fo, &ftv);
+
     /* 
      * alloc d_buf -- 1 for compressed or strems, many for uncompressed
      */
@@ -189,6 +206,8 @@ int ftio_init(struct ftio *ftio, int fd, int flag)
       }
   
       ftio->flags |= FT_IO_FLAG_ZINIT;
+
+#ifdef HAVE_MMAP
  
       if (flag & FT_IO_FLAG_MMAP) {
 
@@ -197,11 +216,13 @@ int ftio_init(struct ftio *ftio, int fd, int flag)
 
       }
 
+#endif /* HAVE_MMAP */
+
       ftio->zs.avail_out = ftio->rec_size;
       ftio->zs.next_out = (Bytef*)ftio->d_buf;
 
     }
-  
+
     /* mark stream for reading */
     ftio->flags |= FT_IO_FLAG_READ;
 
@@ -261,6 +282,9 @@ int ftio_init(struct ftio *ftio, int fd, int flag)
     /* flags field always valid */
     ftio->fth.fields |= FT_FIELD_HEADER_FLAGS;
 
+    /* preserve FT_IO_FLAG_NO_SWAP */
+    if (flag & FT_IO_FLAG_NO_SWAP)
+      ftio->flags |= FT_IO_FLAG_NO_SWAP;
 
     ret = 0;
 
@@ -432,7 +456,7 @@ int ftio_set_comment(struct ftio *ftio, char *comment)
   if (ftio->fth.comments)
     free(ftio->fth.comments);
 
-  if (!(ftio->fth.comments = (char*)malloc(strlen(comment)))) {
+  if (!(ftio->fth.comments = (char*)malloc(strlen(comment)+1))) {
     fterr_warn("malloc()");
     return -1;
   }
@@ -455,7 +479,7 @@ int ftio_set_cap_hostname(struct ftio *ftio, char *hostname)
   if (ftio->fth.cap_hostname)
     free(ftio->fth.cap_hostname);
 
-  if (!(ftio->fth.cap_hostname = (char*)malloc(strlen(hostname)))) {
+  if (!(ftio->fth.cap_hostname = (char*)malloc(strlen(hostname)+1))) {
     fterr_warn("malloc()");
   }
   strcpy(ftio->fth.cap_hostname, hostname);
@@ -521,6 +545,17 @@ void ftio_set_cap_time(struct ftio *ftio, u_int32 start, u_int32 end)
   ftio->fth.cap_end = end;
 }
 
+/*
+ * function: ftio_set_cap_time_start
+ *
+ * Set the header time for a ftio stream
+ */
+void ftio_set_cap_time_start(struct ftio *ftio, u_int32 start)
+{
+  ftio->fth.fields |= FT_FIELD_CAP_START;
+  ftio->fth.cap_start = start;
+}
+
 /*
  * function: ftio_get_ver
  *
@@ -630,7 +665,8 @@ u_int32 ftio_get_lost(struct ftio *ftio)
  *
  * Free resources allocated with ftio_init()
  * Flush any non empty buffers if stream was initialized for WRITE
- * 
+ * close file descriptor
+ *
  * returns: <0   error
  *          >= 0 okay
  */
@@ -727,11 +763,6 @@ int ftio_close(struct ftio *ftio)
 
       nbytes += n;
 
-      deflateEnd(&ftio->zs);
-      ftio->flags &= ~FT_IO_FLAG_ZINIT;
-
-      free(ftio->z_buf);
-
       ret = 0;
 
     /* no compression */
@@ -761,23 +792,42 @@ int ftio_close(struct ftio *ftio)
 
       ret = 0;
 
-      free (ftio->d_buf);
-
     } /* compression */
 
   } /* io stream enabled for write */
 
-  ret = close(ftio->fd);
-
-  /* return bytes written if no error */
-  if (ret >= 0)
-    ret = nbytes;
 
 ftio_close_out:
 
+  if (ftio->flags & FT_IO_FLAG_WRITE) {
+
+    if (ftio->flags & FT_IO_FLAG_ZINIT) {
+
+      deflateEnd(&ftio->zs);
+      ftio->flags &= ~FT_IO_FLAG_ZINIT;
+      free(ftio->z_buf);
+
+    } else {
+
+      free (ftio->d_buf);
+
+    }
+
+  } /* FT_IO_FLAG_WRITE */
+
+  /* don't lose error condition if close() is a success */
+  if (ret < 0)
+    ret = close(ftio->fd);
+  else
+    close(ftio->fd);
+
+  /* no error and writing? then return bytes written */
+  if ((ftio->flags & FT_IO_FLAG_WRITE) && (ret >= 0))
+    ret = nbytes;
+
   return ret;
   
-}
+} /* ftio_close */
 
 /*
  * function: ftio_zstat_print
@@ -870,7 +920,7 @@ void *ftio_read(struct ftio *ftio)
         boff = ftio->d_start;
         ftio->d_start += ftio->rec_size;
 
-        ret = (void*)ftio->mr+boff;
+        ret = (char*)ftio->mr+boff;
         goto ftio_read_out;
       }
 
@@ -978,7 +1028,7 @@ void *ftio_read(struct ftio *ftio)
       /* ftio_interrupt(ftio); */
       /* continue */
 
-      ret = (void*)ftio->d_buf+boff;
+      ret = (char*)ftio->d_buf+boff;
       goto ftio_read_out;
 
     /* no, perform a read() to try for more */
@@ -1387,6 +1437,8 @@ int ftio_write_header(struct ftio *ftio)
   /* save write size */
   ftio->fth.size = head_off_d;
 
+  ret = n;
+
 ftio_write_header_out:
 
   if (restore) {
@@ -1397,8 +1449,6 @@ ftio_write_header_out:
 
   }
 
-  ret = n;
-
   if (enc_buf)
     free(enc_buf);
 
@@ -1426,7 +1476,7 @@ int ftio_write(struct ftio *ftio, void *data)
   ret = -1;
   nbytes = 0;
  
-  if (!ftio->flags & FT_IO_FLAG_NO_SWAP) {
+  if (!(ftio->flags & FT_IO_FLAG_NO_SWAP)) {
 #if BYTE_ORDER == BIG_ENDIAN
     if (ftio->fth.byte_order == FT_HEADER_LITTLE_ENDIAN)
       ftio->swapf((void*)data);
@@ -1517,7 +1567,7 @@ int ftio_write(struct ftio *ftio, void *data)
 
 ftio_write_out:
 
-  if (!ftio->flags & FT_IO_FLAG_NO_SWAP) {
+  if (!(ftio->flags & FT_IO_FLAG_NO_SWAP)) {
 #if BYTE_ORDER == BIG_ENDIAN
     if (ftio->fth.byte_order == FT_HEADER_LITTLE_ENDIAN)
       ftio->swapf((void*)data);
@@ -1560,15 +1610,14 @@ void ftio_header_print(struct ftio *ftio, FILE *std, char cc)
 
   fields = ftio->fth.fields;
 
-  streaming2 = (flags & FT_HEADER_FLAG_STREAMING);
-  if (flags & FT_HEADER_FLAG_PRELOADED)
-    streaming2 = 0;
-
   if (fields & FT_FIELD_HEADER_FLAGS)
     flags = ftio->fth.flags;
   else 
     flags = 0;
 
+  streaming2 = (flags & FT_HEADER_FLAG_STREAMING);
+  if (flags & FT_HEADER_FLAG_PRELOADED)
+    streaming2 = 0;
 
   if (flags & FT_HEADER_FLAG_STREAMING)
     fprintf(std, "%c\n%c mode:                 streaming\n", cc, cc);
@@ -1603,7 +1652,8 @@ void ftio_header_print(struct ftio *ftio, FILE *std, char cc)
           ctime((time_t*)&fth->cap_end));
 
       period = fth->cap_end - fth->cap_start;
-      fprintf(std, "%c capture period:       %lu seconds\n", cc, period);
+      if ((fields & FT_FIELD_CAP_END) && (fields & FT_FIELD_CAP_START))
+        fprintf(std, "%c capture period:       %lu seconds\n", cc, period);
 
     }
 
@@ -1638,18 +1688,68 @@ void ftio_header_print(struct ftio *ftio, FILE *std, char cc)
       agg_ver = ftio->fth.agg_version;
       agg_method = ftio->fth.agg_method;
 
-      if (agg_method == 1)
-        agg_name = "AS";
-      else if (agg_method == 2)
-        agg_name = "Protocol Port";
-      else if (agg_method == 3)
-        agg_name = "Source Prefix";
-      else if (agg_method == 4)
-        agg_name = "Destination Prefix";
-      else if (agg_method == 5)
-        agg_name = "Prefix";
-      else
-        agg_name = "Unknown";
+      switch (agg_method) {
+
+        case 1:
+          agg_name = "AS";
+          break;
+
+        case 2:
+          agg_name = "Protocol Port";
+          break;
+
+        case 3:
+          agg_name = "Source Prefix";
+          break;
+
+        case 4:
+          agg_name = "Destination Prefix";
+          break;
+
+        case 5:
+          agg_name = "Prefix";
+          break;
+
+        case 6:
+          agg_name = "Destination";
+          break;
+
+        case 7:
+          agg_name = "Source Destination";
+          break;
+
+        case 8:
+          agg_name = "Full Flow";
+          break;
+
+        case 9:
+          agg_name = "ToS AS";
+          break;
+
+        case 10:
+          agg_name = "ToS Proto Port";
+          break;
+
+        case 11:
+          agg_name = "ToS Source Prefix";
+          break;
+
+        case 12:
+          agg_name = "ToS Destination Prefix";
+          break;
+
+        case 13:
+          agg_name = "ToS Prefix";
+          break;
+
+        case 14:
+          agg_name = "ToS Prefix Port";
+          break;
+
+        default:
+          agg_name = "Unknown";
+
+      } /* switch */
 
     if (fields & FT_FIELD_AGG_VER)
       fprintf(std, "%c export agg_version:   %u\n", cc, (int)agg_ver);
@@ -1792,6 +1892,42 @@ void *ftio_rec_swapfunc(struct ftio *ftio)
               ret = fts3rec_swap_v8_5;
               break;
 
+            case 6:
+              ret = fts3rec_swap_v8_6;
+              break;
+
+            case 7:
+              ret = fts3rec_swap_v8_7;
+              break;
+
+            case 8:
+              ret = fts3rec_swap_v8_8;
+              break;
+
+            case 9:
+              ret = fts3rec_swap_v8_9;
+              break;
+
+            case 10:
+              ret = fts3rec_swap_v8_10;
+              break;
+
+            case 11:
+              ret = fts3rec_swap_v8_11;
+              break;
+
+            case 12:
+              ret = fts3rec_swap_v8_12;
+              break;
+
+            case 13:
+              ret = fts3rec_swap_v8_13;
+              break;
+
+            case 14:
+              ret = fts3rec_swap_v8_14;
+              break;
+
             default:
               fterr_warnx("Unsupported agg_method %d", (int)agg_method);
               ret = (void*)0L;
@@ -1800,6 +1936,10 @@ void *ftio_rec_swapfunc(struct ftio *ftio)
           } /* switch agg_method */
           break;
 
+        case 1005:
+          ret = fts3rec_swap_v1005;
+          break;
+
         default:
           fterr_warnx("Unsupported d_version %d", (int)ftio->fth.d_version);
           ret = (void*)0L;
@@ -1825,19 +1965,19 @@ void *ftio_rec_swapfunc(struct ftio *ftio)
  * Return the size of a fts3rec_* based on the d_version and agg_method
  *
  */
-int ftrec_size(struct ftver ver)
+int ftrec_size(struct ftver *ver)
 {
 
   int ret;
 
-  switch (ver.s_version) {
+  switch (ver->s_version) {
 
     case 1:
       ret = sizeof (struct fts1rec_compat);
       break;
 
     case 3:
-      switch (ver.d_version) {
+      switch (ver->d_version) {
 
         case 1:
           ret = sizeof (struct fts3rec_v1);
@@ -1856,13 +1996,13 @@ int ftrec_size(struct ftver ver)
           break;
 
         case 8:
-          if (ver.agg_version != 2) {
-            fterr_warnx("Unsupported agg_version %d", (int)ver.agg_version);
+          if (ver->agg_version != 2) {
+            fterr_warnx("Unsupported agg_version %d", (int)ver->agg_version);
             ret = -1;
             break;
           }
 
-          switch (ver.agg_method) {
+          switch (ver->agg_method) {
 
             case 1:
               ret = sizeof (struct fts3rec_v8_1);
@@ -1884,16 +2024,56 @@ int ftrec_size(struct ftver ver)
               ret = sizeof (struct fts3rec_v8_5);
               break;
 
+            case 6:
+              ret = sizeof (struct fts3rec_v8_6);
+              break;
+
+            case 7:
+              ret = sizeof (struct fts3rec_v8_7);
+              break;
+
+            case 8:
+              ret = sizeof (struct fts3rec_v8_8);
+              break;
+
+            case 9:
+              ret = sizeof (struct fts3rec_v8_9);
+              break;
+
+            case 10:
+              ret = sizeof (struct fts3rec_v8_10);
+              break;
+
+            case 11:
+              ret = sizeof (struct fts3rec_v8_11);
+              break;
+
+            case 12:
+              ret = sizeof (struct fts3rec_v8_12);
+              break;
+
+            case 13:
+              ret = sizeof (struct fts3rec_v8_13);
+              break;
+
+            case 14:
+              ret = sizeof (struct fts3rec_v8_14);
+              break;
+
             default:
-              fterr_warnx("Unsupported agg_method %d", (int)ver.agg_method);
+              fterr_warnx("Unsupported agg_method %d", (int)ver->agg_method);
               ret = -1;
               break;
 
           } /* switch agg_method */
           break;
 
+        case 1005:
+          ret = sizeof (struct fts3rec_v1005);
+          break;
+
         default:
-          fterr_warnx("Unsupported d_version %d", (int)ver.d_version);
+          fterr_warnx("Unsupported d_version %d", (int)ver->d_version);
           ret = -1;
           break;
 
@@ -1901,7 +2081,7 @@ int ftrec_size(struct ftver ver)
       break;
 
     default:
-      fterr_warnx("Unsupported s_version %d", (int)ver.s_version);
+      fterr_warnx("Unsupported s_version %d", (int)ver->s_version);
       ret = -1;
       break;
 
@@ -1911,6 +2091,141 @@ int ftrec_size(struct ftver ver)
 
 }
 
+/*
+ * function: ftrec_xfield
+ *
+ * Return the FT_XFIELD* based on the d_version and agg_method
+ *
+ */
+u_int64 ftrec_xfield(struct ftver *ver)
+{
+
+  u_int64 ret;
+
+   switch (ver->d_version) {
+
+     case 1:
+       ret = FT_XFIELD_V1_MASK;
+       break;
+
+     case 5:
+       ret = FT_XFIELD_V5_MASK;
+       break;
+
+     case 6:
+       ret = FT_XFIELD_V6_MASK;
+       break;
+
+     case 7:
+       ret = FT_XFIELD_V7_MASK;
+       break;
+
+     case 8:
+       if (ver->agg_version != 2) {
+         fterr_warnx("Unsupported agg_version %d", (int)ver->agg_version);
+         ret = -1;
+         break;
+       }
+
+       switch (ver->agg_method) {
+
+         case 1:
+           ret = FT_XFIELD_V8_1_MASK;
+           break;
+
+         case 2:
+           ret = FT_XFIELD_V8_2_MASK;
+           break;
+
+         case 3:
+           ret = FT_XFIELD_V8_3_MASK;
+           break;
+
+         case 4:
+           ret = FT_XFIELD_V8_4_MASK;
+           break;
+
+         case 5:
+           ret = FT_XFIELD_V8_5_MASK;
+           break;
+
+         case 6:
+           ret = FT_XFIELD_V8_6_MASK;
+           break;
+
+         case 7:
+           ret = FT_XFIELD_V8_7_MASK;
+           break;
+
+         case 8:
+           ret = FT_XFIELD_V8_8_MASK;
+           break;
+
+         case 9:
+           ret = FT_XFIELD_V8_9_MASK;
+           break;
+
+         case 10:
+           ret = FT_XFIELD_V8_10_MASK;
+           break;
+
+         case 11:
+           ret = FT_XFIELD_V8_11_MASK;
+           break;
+
+         case 12:
+           ret = FT_XFIELD_V8_12_MASK;
+           break;
+
+         case 13:
+           ret = FT_XFIELD_V8_13_MASK;
+           break;
+
+         case 14:
+           ret = FT_XFIELD_V8_14_MASK;
+           break;
+
+         default:
+           fterr_warnx("Unsupported agg_method %d", (int)ver->agg_method);
+           ret = -1;
+           break;
+
+       } /* switch agg_method */
+       break;
+
+     case 1005:
+       ret = FT_XFIELD_V1005_MASK;
+       break;
+
+     default:
+       fterr_warnx("Unsupported d_version %d", (int)ver->d_version);
+       ret = -1;
+       break;
+
+   } /* switch v8 export */
+
+  return ret;
+
+} /* ftrec_xfield */
+
+/*
+ * function: ftio_xfield
+ *
+ * Return the FT_XFIELD*
+ *
+ */
+u_int64 ftio_xfield(struct ftio *ftio)
+{
+  struct ftver ver;
+
+  ver.d_version = ftio->fth.d_version;
+  ver.s_version = ftio->fth.s_version;
+  ver.agg_method = ftio->fth.agg_method;
+  ver.agg_version = ftio->fth.agg_version;
+
+  return ftrec_xfield(&ver);
+}
+
 /*
  * function: ftio_rec_size
  *
@@ -1920,15 +2235,16 @@ int ftrec_size(struct ftver ver)
  */
 int ftio_rec_size(struct ftio *ftio)
 {
-
   struct ftver ver;
+
   ver.d_version = ftio->fth.d_version;
   ver.s_version = ftio->fth.s_version;
   ver.agg_method = ftio->fth.agg_method;
   ver.agg_version = ftio->fth.agg_version;
 
-  return ftrec_size(ver);
-}
+  return ftrec_size(&ver);
+
+} /* ftio_rec_size */
 
 
 /*
@@ -1937,10 +2253,7 @@ int ftio_rec_size(struct ftio *ftio)
  * read()'s n bytes from fd
  * returns # of butes read, or -1 for error
  */
-int readn(fd, ptr, nbytes)
-register int fd;
-register char *ptr;
-register int nbytes;
+int readn(register int fd, register void *ptr, register int nbytes)
 {
 
   int nleft, nread;
@@ -1954,7 +2267,7 @@ register int nbytes;
         break;
 
       nleft -= nread;
-      ptr += nread;
+      (char*)ptr += nread;
   }
   return (nbytes - nleft);
 } /* readn */
@@ -1979,7 +2292,7 @@ int writen(register int fd, register void *ptr, register int nbytes)
       return(nwritten); /* error */
 
     nleft -= nwritten;
-    ptr += nwritten;
+    (char*)ptr += nwritten;
   }
   return(nbytes - nleft);
 } /* writen */
@@ -2019,14 +2332,15 @@ int ftiheader_read(int fd, struct ftiheader *ihead)
   }
 
   if (n != sizeof head_gen) {
-    fterr_warnx("short read while loading header top");
+    fterr_warnx(
+      "ftiheader_read(): Warning, short read while loading header top.");
     goto ftiheader_read_out;
   }
         
   /* verify magic */
   if ((head_gen.magic1 != FT_HEADER_MAGIC1) ||   
       (head_gen.magic2 != FT_HEADER_MAGIC2)) {
-      fterr_warnx("Bad magic number");
+      fterr_warnx("ftiheader_read(): Warning, bad magic number");
       goto ftiheader_read_out;
   }
 
@@ -2061,7 +2375,8 @@ int ftiheader_read(int fd, struct ftiheader *ihead)
     }
 
     if (n != sizeof head_off_d) {
-      fterr_warnx("short read while loading header data offset");
+      fterr_warnx(
+        "ftiheader_read(): Error, short read while loading header data offset.");
       goto ftiheader_read_out;
     }
 
@@ -2236,13 +2551,11 @@ int ftiheader_read(int fd, struct ftiheader *ihead)
 
         case FT_TLV_AGG_VER:
           bcopy(tlv.v, &ihead->agg_version, 1);
-          if (flip) SWAPINT16(ihead->agg_version);
           ihead->fields |= FT_FIELD_AGG_VER;
           break;
 
         case FT_TLV_AGG_METHOD:
           bcopy(tlv.v, &ihead->agg_method, 1);
-          if (flip) SWAPINT16(ihead->agg_method);
           ihead->fields |= FT_FIELD_AGG_METHOD;
           break;
 
@@ -2658,3 +2971,22 @@ ftio_interrupt_out:
   return ret;
 
 } /* ftio_interrupt */
+
+/*
+ * function: ftio_check_xfield
+ *
+ * Check if xfield_need bits are available in stream
+ *
+ * returns: 0  ok
+ *          != fail - a field required is not available.
+ */
+int ftio_check_xfield(struct ftio *ftio, u_int64 xfield_need)
+{
+
+  if ((xfield_need & ftio->xfield) != xfield_need)
+    return -1;
+  else
+    return 0;
+
+} /* ftio_xfields */
+
