@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: ftrec.c,v 1.12 2003/02/13 02:38:42 maf Exp $
+ *      $Id: ftrec.c,v 1.13 2003/11/30 22:56:45 maf Exp $
  */
 
 #include "ftconfig.h"
@@ -72,6 +72,9 @@ void ftrec_xlate_7to6(struct fts3rec_v7 *rec_v7, struct fts3rec_v6 *rec_v6);
 void ftrec_xlate_7to1005(struct fts3rec_v7 *rec_v7,
   struct fts3rec_v1005 *rec_v1005);
 
+void ftrec_xlate_1005to5(struct fts3rec_v1005 *rec_v1005,
+  struct fts3rec_v5 *rec_v5);
+
 /*
  * function ftrec_compute_mask
  *
@@ -209,6 +212,10 @@ void *ftrec_xlate_func(struct ftver *in_ftv, struct ftver *out_ftv)
     else if (out_ftv->d_version == 1005)
       return ftrec_xlate_7to1005;
 
+  } else if (in_ftv->d_version == 1005) {
+
+    if (out_ftv->d_version == 5)
+      return ftrec_xlate_1005to5;
   }
 
   return (void*)0L;
@@ -228,6 +235,8 @@ void ftrec_xlate(void *in_rec, struct ftver *in_ftv, void *out_rec,
   void (*func)(void *in_rec, void *out_rec);
 
   func = ftrec_xlate_func(in_ftv, out_ftv);
+  if (!func)
+    return; /* XXX: should provide a return code */
   func(in_rec, out_rec);
 
 } /* ftrec_xlate */
@@ -710,6 +719,38 @@ void ftrec_xlate_7to1005(struct fts3rec_v7 *rec_v7,
 
 } /* ftrec_xlate_7to1005 */
 
+void ftrec_xlate_1005to5(struct fts3rec_v1005 *rec_v1005,
+  struct fts3rec_v5 *rec_v5)
+{
+  bzero(rec_v5, sizeof (struct fts3rec_v5));
+
+  rec_v5->unix_secs = rec_v1005->unix_secs;
+  rec_v5->unix_nsecs = rec_v1005->unix_nsecs;
+  rec_v5->sysUpTime = rec_v1005->sysUpTime;
+  rec_v5->exaddr = rec_v1005->exaddr;
+  rec_v5->srcaddr = rec_v1005->srcaddr;
+  rec_v5->dstaddr = rec_v1005->dstaddr;
+  rec_v5->nexthop = rec_v1005->nexthop;
+  rec_v5->input = rec_v1005->input;
+  rec_v5->output = rec_v1005->output;
+  rec_v5->dPkts = rec_v1005->dPkts;
+  rec_v5->dOctets = rec_v1005->dOctets;
+  rec_v5->First = rec_v1005->First;
+  rec_v5->Last = rec_v1005->Last;
+  rec_v5->srcport = rec_v1005->srcport;
+  rec_v5->dstport = rec_v1005->dstport;
+  rec_v5->prot = rec_v1005->prot;
+  rec_v5->tos = rec_v1005->tos;
+  rec_v5->tcp_flags = rec_v1005->tcp_flags;
+  rec_v5->engine_type = rec_v1005->engine_type;
+  rec_v5->engine_id = rec_v1005->engine_id;
+  rec_v5->src_mask = rec_v1005->src_mask;
+  rec_v5->dst_mask = rec_v1005->dst_mask;
+  rec_v5->src_as = rec_v1005->src_as;
+  rec_v5->dst_as = rec_v1005->dst_as;
+
+} /* flow_xlate_1005to5 */
+
 /*
  * function fts3rec_compute_offsets
  *
