@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: ftsym.c,v 1.4 2003/02/13 02:38:42 maf Exp $
+ *      $Id: ftsym.c,v 1.5 2003/04/26 03:12:03 maf Exp $
  */
 
 #include "ftconfig.h"
@@ -49,8 +49,7 @@
  *
  *   allocate and initialize new symbol table structure
  *
- *   FILENAME -      filename to load ASCII table
- *
+ * fname - filename to load ASCII table
  * returns allocated structure or 0L for error.
  *
  */
@@ -63,6 +62,10 @@ struct ftsym *ftsym_new(char *fname)
   int fd, ret;
   u_int32 hash;
 
+  /* no filename? */
+  if (!fname)
+    return (struct ftsym*)0L;
+
   fd = -1;
   ret = -1;
 
