@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: fttag.c,v 1.18 2003/12/01 05:48:17 maf Exp $
+ *      $Id: fttag.c,v 1.19 2004/01/05 17:55:37 maf Exp $
  */
 
 #include "ftconfig.h"
@@ -200,42 +200,10 @@ static struct jump pjump[] = {{"tag-action", 0, parse_action},
  *
  * Process fname into fttag.
  *
- * tag file format:
- *
- * tag-action OSU
- * # src-prefix|dst-prefix|prefixx
- *  type src-prefi
- *  match 128.146/16 set-src 100
- *  match 164.107/16 set-src 100
- *  match 140.254/16 set-src 100
- *
- * tag-action OSU2
- *  # src-as|dst-as|as
- *  type src-as
- *  match 159 set-src 0x1
- *  match 600 or-src 0x2
- *
- * tag-action OSU3  
- *  type next-hop   
- *  match 199.18.2.2 set-src 100
- *  match 199.18.2.1 set-src 101
- *
- * tag-definition OSUrouter1
- *  term
- *   exporter 128.146.1.1
- *   input-filter 1,2,3,4
- *   output-filter !5-9
- *   action OSU
- *   action OSU2
- *  term
- *   exporter 128.146.2.1
- *   input-filter 1
- *   output-filter 5
- *
  * returns: 0  ok
  *          <0 fail
  */
-int fttag_load(struct fttag *fttag, char *fname)
+int fttag_load(struct fttag *fttag, struct ftvar *ftvar, char *fname)
 {
   static int rn_init_called;
   struct stat sb;
@@ -243,6 +211,7 @@ int fttag_load(struct fttag *fttag, char *fname)
   struct line_parser lp;
   int fd, ret, found;
   char *buf, *buf2, *c;
+  char sbuf[FT_LP_MAXLINE];
 
   ret = -1;
   buf = (char*)0L;
@@ -302,7 +271,18 @@ int fttag_load(struct fttag *fttag, char *fname)
       goto load_tags_done;
     }
 
-    lp.buf = c;
+    /* do variable substitutions first */
+    if (ftvar) {
+      if (ftvar_evalstr(ftvar, c, sbuf, sizeof(sbuf)) < 0) {
+        fterr_warnx("ftvar_evalstr(): failed");
+        goto load_tags_done;
+      }
+    } else {
+      strncpy(sbuf, c, sizeof(sbuf));
+      sbuf[sizeof(sbuf)-1] = 0;
+    }
+      
+    lp.buf = sbuf;
 
     /* first word */
     NEXT_WORD(&lp.buf, c);
@@ -1466,7 +1446,12 @@ int parse_def_action(struct line_parser *lp, struct fttag *fttag)
 
   bzero(ftdta, sizeof *ftdta);
 
-  ftdta->name = c;
+  if (!(ftdta->name = (char*)malloc(strlen(c)+1))) {
+    fterr_warn("malloc()");
+    free(ftdta);
+    return -1;
+  }
+  strcpy(ftdta->name, c);
 
   FT_STAILQ_INSERT_TAIL(&lp->cur_def_term->actions, ftdta, chain);
 
@@ -1601,6 +1586,9 @@ void fttag_free(struct fttag *fttag)
 
         ftdta = FT_STAILQ_FIRST(&ftdt->actions);
 
+        if (ftdta->name)
+          free(ftdta->name);
+
         FT_STAILQ_REMOVE_HEAD(&ftdt->actions, chain);
 
         free(ftdta);
