@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: ftvar.c,v 1.4 2003/11/30 22:57:10 maf Exp $
+ *      $Id: ftvar.c,v 1.5 2004/01/05 17:56:19 maf Exp $
  */
 
 #include "ftconfig.h"
@@ -262,18 +262,21 @@ void ftvar_clear(struct ftvar *ftvar, char *name)
 int ftvar_evalstr(struct ftvar *ftvar, char *src, char *dst, int dstlen)
 {
   struct ftvar_entry *ftve;
-  char *s, *d, *v, saved, *sm, *tmp;
-  int len, ret, invar;
+  char *s, *d, *v, *ve, *sm, *tmp;
+  int len, ret, inbrace, x;
+  char *vexp, *varname, *def;
 
   d = dst;
   len = 0;
   ret = -1;
-  invar = 0;
-  saved = 0;
+  inbrace = 0;
+  vexp = (char*)0L;
+  sm = (char*)0L;
+  def = (char*)0L;
 
   /* preserve source string */
   if (!(sm = (char*)malloc(strlen(src)+1))) {
-    fterr_warnx("malloc(%d)", strlen(src)+1);
+    fterr_warnx("ftvar: malloc(%d)", strlen(src)+1);
     return -1;
   }
 
@@ -295,50 +298,129 @@ int ftvar_evalstr(struct ftvar *ftvar, char *src, char *dst, int dstlen)
 
     /* start of var? */
     if (*s == '@') {
-      invar = 1; /* yes, work to do later */
-    } else {
-      d[len++] = *s++; /* no, copy */
-    }
-
-    /* end of dst buf? */
-    if ((len+1) == dstlen)
-      goto done;
-
-    /* got a var to process? */
-    if (invar) {
 
       /* variable starts after the @ */
       v = ++s;
 
-      /* find end of variable name */
-      while (*s && isalpha(*s))
-        ++s;
+      /* end of variable initialized to start */
+      ve = v;
 
-      /* null terminate it, saving potential next char */
-      saved = *s;
-      *s = 0;
+      /* is variable in a brace? yes then must end on a brace */
+      if (*v && (*v == '{')) {
+
+        inbrace = 1;
+
+        while (*ve && (*ve != '}'))
+          ++ve;
+
+        if (*ve != '}')
+          fterr_errx(1, "ftvar: %s: Missing }", v);
+
+        ++ve;
+
+      /* else it ends on the first non alphanumeric char */
+      } else {
+
+        while (*ve && isalnum(*ve))
+          ++ve;
+
+      }
+
+      /* copy out the variable expression, braces and all */
+      x = ve - v;
+      if (!(vexp = (char*)malloc(x+1)))
+        fterr_errx(1, "ftvar: malloc(%d)", x+1);
+
+      strncpy(vexp, v, x);
+      vexp[x] = 0;
+
+      /*
+       * either have form !inbrace VARIABLE
+       *    or
+       * inbrace VARIABLE:-foo
+       *
+       * if it's the former can just proceed with substitution.
+       *
+       * The latter requires checking for the :, processing the
+       * command (now only -) if the variable substitution fails
+       *
+       * there's also a special case of @{VAR}
+       */
+
+      varname = vexp;
+
+      if (inbrace) {
+
+        /* skip over opening brace */
+        ++varname;
+
+        /* find the first non alphanumeric */
+        tmp = varname;
+        while (*tmp && isalnum(*tmp))
+          ++tmp;
+
+        /* if its an end brace then done with special processing */
+        if (*tmp == '}') {
+          *tmp = 0;
+          goto skipspecial;
+        }
+
+        /* better be a : */
+        if (*tmp != ':')
+          fterr_errx(1, "ftvar: %s: missing :", vexp);
+
+        /* : to null so the variable name is null terminated */
+        *tmp++ = 0;
+
+        /* only special type is - (default) */
+
+        if (*tmp != '-')
+          fterr_errx(1, "ftvar: %s: expecting -", vexp);
+
+        /* default expression is after the - */
+        def = ++tmp;
+
+        /* drop the trailing } */
+        while (*tmp && *tmp != '}')
+          ++tmp;
+        *tmp = 0;
+
+      }
+
+skipspecial:
 
       /* lookup var */
-      if ((ftve = ftvar_find(ftvar, v)))
+      if ((ftve = ftvar_find(ftvar, varname)))
         tmp = ftve->val; /* found it, copy in the value */
       else
-        tmp = --v; /* no, copy in the literal with the @ */
+        tmp = (def) ? def : (char*)0L;
 
-      while (*tmp && ((len+1) != dstlen))
-        d[len++] = *tmp++;
+      /* got a substitution */
+      if (tmp)
+        while (*tmp && ((len+1) != dstlen))
+          d[len++] = *tmp++;
 
       /* end of dst buf? */
       if ((len+1) == dstlen)
         goto done;
 
-      /* restore the character lost due to null terminating var name */
-      if (saved)
-        *s = saved, saved = 0;
-      else
-        ++s;
+      /* skip variable name in original string */
+      s = ve;
 
-      /* done processing variable */
-      invar = 0;
+      /* reset */
+      inbrace = 0;
+      def = (char*)0L;
+      if (vexp)
+        free(vexp);
+      vexp = (char*)0L;
+
+    } else {
+
+      d[len++] = *s++; /* no, copy */
+
+      /* end of dst buf? */
+      if ((len+1) == dstlen)
+        goto done;
 
     }
     
@@ -349,7 +431,13 @@ int ftvar_evalstr(struct ftvar *ftvar, char *src, char *dst, int dstlen)
 done:
 
   dst[len] = 0;
-  free(sm);
+
+  if (sm)
+    free(sm);
+
+  if (vexp)
+    free(vexp);
+
   return ret;
 
 } /* ftvar_evalstr */
