@@ -20,7 +20,7 @@ static int yygrowstack();
 #line 2 "aclyacc.y"
 
 #include "ftconfig.h"
-#include "ftlib.h"
+#include <ftlib.h>
 
 #include "acl2.h"
 #include <stdio.h> /* XXX REMOVE */
