@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: flow-capture.c,v 1.77 2003/11/29 06:43:08 maf Exp $
+ *      $Id: flow-capture.c,v 1.78 2004/01/05 17:56:50 maf Exp $
  */
 
 #include "ftconfig.h"
@@ -153,6 +153,7 @@ char **argv;
   struct ftxlate ftxlate;
   struct fttag_def *ftd;
   struct ftfil_def *ftfd;
+  struct ftvar ftvar;
   struct ftxlate_def *ftxd;
   struct fts3rec_offsets fo;
   struct client_rec *client_rec, *client_rec2;
@@ -187,6 +188,8 @@ char **argv;
   bzero (&fttag, sizeof fttag);
   bzero (&ftfil, sizeof ftfil);
   bzero (&ftxlate, sizeof ftxlate);
+  bzero (&ftvar, sizeof ftvar);
+
   FT_LIST_INIT(&client.list);
   stat_interval = 0;
   stat_next = -1;
@@ -211,6 +214,10 @@ char **argv;
   fterr_setid(argv[0]);
   fterr_setexit(fterr_exit_handler);
 
+  /* init var binding */
+  if (ftvar_new(&ftvar) < 0)
+    fterr_errx(1, "ftvar_new(): failed");
+
   /* defaults + default compression */
   ftset_init(&ftset, Z_DEFAULT_COMPRESSION);
 
@@ -243,7 +250,7 @@ char **argv;
   pidfile = CAPTURE_PIDFILE;
 
   while ((i = getopt(argc, argv,
-    "b:c:C:d:De:E:f:F:hn:N:p:S:t:T:uV:w:x:X:z:R:")) != -1)
+    "b:c:C:d:De:E:f:F:hn:N:p:S:t:T:uv:V:w:x:X:z:R:")) != -1)
   
     switch (i) {
 
@@ -346,6 +353,11 @@ char **argv;
     case 'i': /* preserve inherited umask */
       preserve_umask = 1;
       break;
+
+    case 'v': /* variable */
+      if (ftvar_pset(&ftvar, optarg) < 0)
+        fterr_errx(1, "ftvar_pset(%s): failed", optarg);
+      break;
       
     case 'V': /* PDU version */
       v_flag = 1;
@@ -1049,7 +1061,7 @@ skip_pdu_decode:
           fterr_info("Reloading tags.");
         }
     
-        if (fttag_load(&fttag, tag_fname) < 0)
+        if (fttag_load(&fttag, &ftvar, tag_fname) < 0)
           fterr_errx(1, "fttag_load(): failed");
     
         if (!(ftd = fttag_def_find(&fttag, tag_active)))
@@ -1066,7 +1078,7 @@ skip_pdu_decode:
           fterr_info("Reloading filters.");
         }
         
-        if (ftfil_load(&ftfil, filter_fname))
+        if (ftfil_load(&ftfil, &ftvar, filter_fname))
           fterr_errx(1, "ftfil_load(%s): failed", filter_fname);
             
         if (!(ftfd = ftfil_def_find(&ftfil, filter_active)))
@@ -1086,7 +1098,7 @@ skip_pdu_decode:
           fterr_info("Reloading translations.");
         }
         
-        if (ftxlate_load(&ftxlate, xlate_fname))
+        if (ftxlate_load(&ftxlate, &ftvar, xlate_fname))
           fterr_errx(1, "ftxlate_load(%s): failed", xlate_fname);
             
         if (!(ftxd = ftxlate_def_find(&ftxlate, xlate_active)))
