@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: flow-dscan.c,v 1.28 2003/11/25 10:14:27 maf Exp $
+ *      $Id: flow-dscan.c,v 1.29 2005/05/10 15:53:11 maf Exp $
  */
 
 #include "ftconfig.h"
@@ -560,7 +560,7 @@ sup:
       ager(&ds, total_flows32);
 
 skip2:
-
+    continue;
 
   } /* while rec */
 
@@ -719,7 +719,7 @@ void sig_hup_handler(int sig)
 void ager(struct dscan_state *ds, u_int32 total_flows32)
 {
   static int ager_i;
-  int i, work;
+  int i, work, picky_gcc;
   struct dscan_rec *drp, *odrp, *drp2;
   struct dscan_dst *ddp, *oddp, *ddp2;
   u_int32 i32;
@@ -806,6 +806,7 @@ void ager(struct dscan_state *ds, u_int32 total_flows32)
   fterr_info("ager: reset hash run");
 
 skip3:
+  picky_gcc = 1;
 
 } /* ager */
 
