@@ -23,11 +23,11 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: flow-expire.c,v 1.15 2003/02/13 02:38:59 maf Exp $
+ *      $Id: flow-expire.c,v 1.16 2003/04/02 18:03:01 maf Exp $
  */
 
 #include "ftconfig.h"
-#include "ftlib.h"
+#include <ftlib.h>
 
 #include <sys/types.h>
 #include <sys/param.h>
