@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: flow-fanout.c,v 1.41 2003/11/30 23:38:37 maf Exp $
+ *      $Id: flow-fanout.c,v 1.44 2005/05/10 15:52:52 maf Exp $
  */
 
 #include "ftconfig.h"
@@ -113,6 +113,7 @@ int main(int argc, char **argv)
   struct ftfil_def *ftfd;
   struct fts3rec_offsets fo;
   struct ftset ftset;
+  struct ftvar ftvar;
   struct peer *peers;
   struct ftipmask ftipmask;
   u_int32 flows_corrupt, flows_lost, flows_reset, hash, privacy_mask;
@@ -137,6 +138,7 @@ int main(int argc, char **argv)
   bzero(&ftch_recexp, sizeof ftch_recexp);
   bzero(&tv, sizeof tv);
   bzero(&ftfil, sizeof ftfil);
+  bzero(&ftvar, sizeof ftvar);
   stat_interval = 0;
   stat_next = -1;
   src_ip_spoof = 0; /* no */
@@ -144,6 +146,10 @@ int main(int argc, char **argv)
   send_nobufs = 0;
   reload_flag = 1; /* yes */
 
+  /* init var binding */
+  if (ftvar_new(&ftvar) < 0)
+    fterr_errx(1, "ftvar_new(): failed");
+
   filter_fname = FT_PATH_CFG_FILTER;
   filter_active = (char*)0L;
   ftfd = (struct ftfil_def*)0L;
@@ -163,7 +169,7 @@ int main(int argc, char **argv)
   tx_delay = 0;
   detach = 1;
 
-  while ((i = getopt(argc, argv, "A:d:Df:F:hm:p:sS:V:x:")) != -1)
+  while ((i = getopt(argc, argv, "A:d:Df:F:hm:p:sS:v:V:x:")) != -1)
     switch (i) {
 
     case 'A': /* AS substitution */
@@ -212,6 +218,11 @@ int main(int argc, char **argv)
         fterr_errx(1, "Stat interval must be between 0 and 60.");
       break;
 
+    case 'v': /* variable */
+      if (ftvar_pset(&ftvar, optarg) < 0)
+        fterr_errx(1, "ftvar_pset(%s): failed", optarg);
+      break;
+
     case 'V': /* PDU version */
       n = sscanf(optarg, "%u.%u", &v1, &v2);
       if (n == 1) {
@@ -411,7 +422,8 @@ int main(int argc, char **argv)
 
   /* default UDP listen port is FT_PORT */
   ftnet.dst_port = (ftpi.dst_port) ? ftpi.dst_port : FT_PORT;
-  
+ 
+  ftnet.loc_addr.sin_family = AF_INET;
   ftnet.loc_addr.sin_addr.s_addr = htonl(ftpi.loc_ip);
   ftnet.loc_addr.sin_port = htons(ftnet.dst_port);
 
@@ -486,7 +498,7 @@ int main(int argc, char **argv)
     /* unicast bind -- multicast support */
     if (bind(ftnet.fd, (struct sockaddr*)&ftnet.loc_addr,
       sizeof(ftnet.loc_addr)) < 0)
-      fterr_err(1, "bind()");
+      fterr_err(1, "bind(loc_addr)");
 
   } /* not multicast group */
 
@@ -499,7 +511,7 @@ mcast_done:
   /* unicast bind -- no multicast support */
   if (bind(ftnet.fd, (struct sockaddr*)&ftnet.loc_addr,
     sizeof(ftnet.loc_addr)) < 0)
-    fterr_err(1, "bind()");
+    fterr_err(1, "bind(loc_addr)");
 
 #endif /* IP_ADD_MEMBERSHIP */
 
@@ -709,7 +721,7 @@ restart_recvmsg:
             fterr_info("Loading filters.");
           }
 
-          if (ftfil_load(&ftfil, filter_fname))
+          if (ftfil_load(&ftfil, &ftvar, filter_fname))
             fterr_errx(1, "ftfil_load(%s): failed", filter_fname);
 
           if (!(ftfd = ftfil_def_find(&ftfil, filter_active)))
@@ -839,10 +851,11 @@ retry:
     
       } /* fte.buf_size */
     
-skip1:
 
     } /* if FD_ISSET */
 
+skip1:
+
     if (sig_quit_flag) {
       fterr_info("SIGQUIT");
       break;
