@@ -23,11 +23,11 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: flow-gen.c,v 1.22 2003/02/13 02:39:00 maf Exp $
+ *      $Id: flow-gen.c,v 1.23 2003/04/02 18:03:01 maf Exp $
  */
 
 #include "ftconfig.h"
-#include "ftlib.h"
+#include <ftlib.h>
 
 #include <stdio.h>
 #include <stdlib.h>
