@@ -23,12 +23,12 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: flow-header.c,v 1.8 2003/02/13 02:39:00 maf Exp $
+ *      $Id: flow-header.c,v 1.9 2003/04/02 18:03:02 maf Exp $
  */
 
 #include "ftconfig.h"
-#include "ftlib.h"
 #include "ftbuild.h"
+#include <ftlib.h>
 
 #include <stdio.h>
 #include <stdlib.h>
