@@ -23,11 +23,11 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: flow-import.c,v 1.12 2003/02/13 02:39:00 maf Exp $
+ *      $Id: flow-import.c,v 1.14 2003/11/11 16:53:57 maf Exp $
  */
 
 #include "ftconfig.h"
-#include "ftlib.h"
+#include <ftlib.h>
 
 #include <sys/time.h>
 #include <sys/types.h>
@@ -49,6 +49,10 @@
   #include <string.h>
 #endif
 
+#if !HAVE_STRSEP
+  char    *strsep (char **, const char *);
+#endif
+
 #include "ftbuild.h"
 #include "cflowd.h"
 
