@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: flow-nfilter.c,v 1.6 2003/04/02 18:03:02 maf Exp $
+ *      $Id: flow-nfilter.c,v 1.7 2004/01/05 17:57:18 maf Exp $
  */
 
 #include "ftconfig.h"
@@ -57,6 +57,7 @@ int main(int argc, char **argv)
   struct ftver ftv_in, ftv_out;
   struct ftset ftset;
   struct fts3rec_offsets fo;
+  struct ftvar ftvar;
   char *rec;
   char *fname, *dname;
   u_int32 total_flows, cap_start, cap_end;
@@ -68,8 +69,13 @@ int main(int argc, char **argv)
 
   bzero(&ftv_in, sizeof ftv_in);
   bzero(&ftv_out, sizeof ftv_out);
+  bzero(&ftvar, sizeof ftvar);
   total_flows = 0;
 
+  /* init var binding */
+  if (ftvar_new(&ftvar) < 0)
+    fterr_errx(1, "ftvar_new(): failed");
+
   fname = FT_PATH_CFG_FILTER;
   dname = "default";
 
@@ -78,7 +84,7 @@ int main(int argc, char **argv)
   /* defaults + no compression */
   ftset_init(&ftset, 0);
 
-  while ((i = getopt(argc, argv, "b:C:d:h?f:F:kz:")) != -1)
+  while ((i = getopt(argc, argv, "b:C:d:f:F:h?kv:z:")) != -1)
 
     switch (i) {
 
@@ -111,6 +117,11 @@ int main(int argc, char **argv)
       keep_input_time = 1;
       break;
 
+    case 'v': /* variable */
+      if (ftvar_pset(&ftvar, optarg) < 0)
+        fterr_errx(1, "ftvar_pset(%s): failed", optarg);
+      break;
+
     case 'z': /* compress level */
       ftset.z_level = atoi(optarg);
       if ((ftset.z_level < 0) || (ftset.z_level > 9))
@@ -130,7 +141,7 @@ int main(int argc, char **argv)
     fterr_errx(1, "Extra arguments starting with %s.", argv[optind]);
 
   /* initialize and load filters */
-  if (ftfil_load(&ftfil, fname))
+  if (ftfil_load(&ftfil, &ftvar, fname))
     fterr_errx(1, "ftfil_load(): failed");
 
   if (!(ftfd = ftfil_def_find(&ftfil, dname))) 
@@ -210,6 +221,8 @@ int main(int argc, char **argv)
 
   ftfil_free(&ftfil);
 
+  ftvar_free(&ftvar);
+
   if (debug > 0) {
     ftprof_end (&ftp, total_flows);
     ftprof_print(&ftp, argv[0], stderr);
