@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: flow-receive.c,v 1.52 2003/11/25 05:37:04 maf Exp $
+ *      $Id: flow-receive.c,v 1.54 2005/05/10 15:52:39 maf Exp $
  */
 
 #include "ftconfig.h"
@@ -82,29 +82,23 @@ int main(int argc, char **argv)
   struct ftver ftv;
   struct ftchash *ftch;
   struct ftchash_rec_exp ftch_recexp, *ftch_recexpp;
-  struct fttag fttag;
-  struct ftfil ftfil;
-  struct fttag_def *ftd;
-  struct ftfil_def *ftfd;
   struct fts3rec_offsets fo;
   time_t now, time_startup;
   int i, n, offset, out_fd, out_fd_plain, one;
   unsigned int v1, v2;
   fd_set rfd;
   char *out_fname;
-  u_int32 filtered_flows, nflows, time_start, time_end;
+  u_int32 nflows, time_start, time_end;
   u_int32 flows_corrupt, flows_lost, flows_reset;
   u_int32 hash;
   char fmt_src_ip[32], fmt_dst_ip[32], fmt_dst_port[32];
   char xl_rec[FT_IO_MAXREC], *out_rec;
-  char *tag_fname, *tag_active;
-  char *filter_fname, *filter_active;
   int stat_interval, stat_next;
 
   time_startup = time((time_t)0L);
 
   out_fname = (char*)0L;
-  filtered_flows = nflows = 0;
+  nflows = 0;
   out_fd_plain = 0;
   out_fd = -1;
   ftset.z_level = 0;
@@ -114,21 +108,10 @@ int main(int argc, char **argv)
   bzero(&ftv, sizeof ftv);
   bzero(&ftpdu, sizeof ftpdu);
   bzero(&ftch_recexp, sizeof ftch_recexp);
-  bzero(&fttag, sizeof fttag);
-  bzero(&ftfil, sizeof ftfil);
   flows_corrupt = flows_lost = flows_reset = 0;
   stat_interval = 0;
   stat_next = -1;
 
-  tag_fname = FT_PATH_CFG_TAG;
-  tag_active = (char*)0L;
-
-  filter_fname = FT_PATH_CFG_FILTER;
-  filter_active = (char*)0L;
-
-  ftfd = (struct ftfil_def*)0L;
-  ftd = (struct fttag_def*)0L;
-
   /* init fterr */
   fterr_setid(argv[0]);
 
@@ -140,7 +123,7 @@ int main(int argc, char **argv)
   ftnet.loc_addr.sin_addr.s_addr = htonl(INADDR_ANY);
   ftnet.loc_addr.sin_port = htons(FT_PORT);
 
-  while ((i = getopt(argc, argv, "b:C:d:f:F:h?o:S:t:T:V:z:")) != -1)
+  while ((i = getopt(argc, argv, "b:C:d:h?o:S:V:z:")) != -1)
 
     switch (i) {
 
@@ -161,14 +144,6 @@ int main(int argc, char **argv)
       debug = atoi(optarg);
       break;
 
-    case 'f': /* filter fname */
-      filter_fname = optarg;
-      break;
-
-    case 'F': /* filter active */
-      filter_active = optarg;
-      break;
-
     case 'h': /* help */
     case '?':
       usage();
@@ -185,14 +160,6 @@ int main(int argc, char **argv)
         fterr_errx(1, "Stat interval must be between 0 and 60.");
       break;
 
-    case 't': /* tag filename */
-      tag_fname = optarg;
-      break;
-      
-    case 'T': /* active tag */
-      tag_active = optarg;
-      break;
-
     case 'V': /* PDU version */
       n = sscanf(optarg, "%u.%u", &v1, &v2);
       if (n == 1) {
@@ -209,7 +176,6 @@ int main(int argc, char **argv)
         fterr_errx(1, "Version scan failed");
       break;
 
-
     case 'z': /* compress level */
       ftset.z_level = atoi(optarg);
       if ((ftset.z_level < 0) || (ftset.z_level > 9))
@@ -223,36 +189,6 @@ int main(int argc, char **argv)
 
     } /* switch */
 
-  /* load tags */
-  if (tag_active) {
-
-    if (ftv.set)
-      fterr_errx(1, "-V not supported with tagging.");
-
-    if (fttag_load(&fttag, tag_fname) < 0)
-      fterr_errx(1, "fttag_load(%s): failed", tag_fname);
-
-    if (!(ftd = fttag_def_find(&fttag, tag_active))) 
-      fterr_errx(1, "fttag_def_find(%s): failed", tag_active);
-
-    /* required for fttag_eval() */
-    ftv.s_version = FT_IO_SVERSION;
-    ftv.d_version = 1005;
-    ftv.set = 1;
-
-  } /* tag_active */
-
-  /* load filters */
-  if (filter_active) {
-
-    if (ftfil_load(&ftfil, filter_fname))
-      fterr_errx(1, "ftfil_load(%s): failed", filter_fname);
-
-    if (!(ftfd = ftfil_def_find(&ftfil, filter_active)))
-      fterr_errx(1, "ftfil_def_find(%s): failed", filter_active);
-
-  } /* filter_active */
-
   /* number of unprocessed options */
   n = argc - optind;
 
@@ -701,30 +637,19 @@ restart_recvmsg:
       /* write decoded flows */
       for (i = 0, offset = 0; i < n; ++i, offset += ftpdu.ftd.rec_size) {
 
-        /* translate version? */
+       /* translate version? */
         if (ftch_recexpp->xlate) {
 
           ftch_recexpp->xlate(ftpdu.ftd.buf+offset, &xl_rec);
 
           out_rec = (char*)&xl_rec;
 
-          /* tagging? */
-          if (tag_active)
-            fttag_def_eval(ftd, (struct fts3rec_v1005*)out_rec);
-
         } else {
 
           out_rec = (char*)ftpdu.ftd.buf+offset;
 
         }
 
-        /* filter? */
-        if (ftfd)
-          if (ftfil_def_eval(ftfd, out_rec, &fo) == FT_FIL_MODE_DENY) {
-            ++filtered_flows;
-            continue;
-          }
-
         ++nflows;
 
         if (ftio_write(&ftio, out_rec) < 0)
@@ -733,14 +658,12 @@ restart_recvmsg:
       } /* for */
 
 skip1:
+      continue;
 
     } /* if FD_ISSET */
 
   } /* while 1 */
 
-  fterr_info("flows stored/dropped by filter %lu/%lu", (u_long)nflows,
-    filtered_flows);
-
   /* rewrite header with updated info */
   if (out_fd_plain) {
   
