@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: flow-report.c,v 1.8 2003/04/02 18:03:02 maf Exp $
+ *      $Id: flow-report.c,v 1.9 2004/01/05 17:59:41 maf Exp $
  */
 
 #include "ftconfig.h"
@@ -66,6 +66,7 @@ int main(int argc, char **argv)
   char *fname, *dname;
   u_int32 total_flows;
   int i, split, done;
+  int usage_call;
 
   /* init fterr */
   fterr_setid(argv[0]);
@@ -73,6 +74,7 @@ int main(int argc, char **argv)
   bzero(&ftv, sizeof ftv);
   bzero(&ftvar, sizeof ftvar);
   total_flows = 0;
+  usage_call = 0;
 
   /* init var binding */
   if (ftvar_new(&ftvar) < 0)
@@ -111,9 +113,13 @@ int main(int argc, char **argv)
 
     case 'h': /* help */
     case '?': 
+      usage();
+      ++usage_call;
+      break;
+
     default:
       usage();
-      exit (1);
+      exit(1);
       break;
 
     } /* switch */
@@ -121,12 +127,12 @@ int main(int argc, char **argv)
   if (argc - optind)
     fterr_errx(1, "Extra arguments starting with %s.", argv[optind]);
 
-  /* initialize and load stats config */
-  if (ftstat_load(&ftstat, fname))
-    fterr_errx(1, "ftstat_load(): failed");
+  if (usage_call)
+    exit(0);
 
-  /* set variable bindings */
-  ftstat_setvarbind(&ftstat, &ftvar);
+  /* initialize and load stats config */
+  if (ftstat_load(&ftstat, &ftvar, fname))
+    fterr_errx(1, "ftstat_load(): failed");
 
   if (!(ftsd = ftstat_def_find(&ftstat, dname))) 
     fterr_errx(1, "ftstat_find_def(%s): failed", dname);
@@ -213,10 +219,24 @@ int main(int argc, char **argv)
 } /* main */
 
 void usage(void) {
-  fprintf(stderr, "Usage: flow-report [h]\n");
-  fprintf(stderr, "       [-d debug_level] [-s stat_fname] [-S stat_definition]\n");
-  fprintf(stderr, "       [-v var=val]\n");
-  fprintf(stderr, "\n%s version %s: built by %s\n", PACKAGE, VERSION, FT_PROG_BUILD);
+
+  static int first;
+
+  if (!first) {
+
+    fprintf(stderr, "Usage: flow-report [-h]\n");
+    fprintf(stderr, "       [-d debug_level] [-s stat_fname] [-S stat_definition]\n");
+    fprintf(stderr, "       [-v var=val]\n");
+    fprintf(stderr, "\n%s version %s: built by %s\n", PACKAGE, VERSION, FT_PROG_BUILD);
+
+    ++first;
+
+  } else {
+
+    fprintf(stderr, "\nAvailable reports:\n\n");
+    ftstat_list_reports(stderr);
+
+  }
 }
 
 void sig_pipe(int signo)
