@@ -23,11 +23,11 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: flow-split.c,v 1.11 2003/02/23 21:42:58 maf Exp $
+ *      $Id: flow-split.c,v 1.12 2003/04/02 18:03:03 maf Exp $
  */
 
 #include "ftconfig.h"
-#include "ftlib.h"
+#include <ftlib.h>
 
 #include <sys/types.h>
 #include <unistd.h>
