@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      $Id: flow-tag.c,v 1.15 2003/04/02 18:03:03 maf Exp $
+ *      $Id: flow-tag.c,v 1.16 2004/01/05 18:00:40 maf Exp $
  */
 
 #include "ftconfig.h"
@@ -58,6 +58,7 @@ int main(int argc, char **argv)
   struct fts3rec_offsets fo;
   struct fttag fttag;
   struct fttag_def *ftd;
+  struct ftvar ftvar;
   int i, keep_input_time;
   u_int32 total_flows, cap_start, cap_end;
   u_int32 time_start, time_end;
@@ -70,6 +71,7 @@ int main(int argc, char **argv)
   bzero(&ftv_in, sizeof ftv_in);
   bzero(&ftv_out, sizeof ftv_out);
   bzero(&fttag, sizeof fttag);
+  bzero(&ftvar, sizeof ftvar);
   tag_defs = FT_PATH_CFG_TAG;
   tag_active = "";
 
@@ -77,13 +79,17 @@ int main(int argc, char **argv)
 
   keep_input_time = 0;
 
+  /* init var binding */
+  if (ftvar_new(&ftvar) < 0)
+    fterr_errx(1, "ftvar_new(): failed");
+
   /* profile */
   ftprof_start (&ftp);
 
   /* defaults + no compression */
   ftset_init(&ftset, 0);
 
-  while ((i = getopt(argc, argv, "b:C:d:fh?klm:s:t:T:V:z:")) != -1)
+  while ((i = getopt(argc, argv, "b:C:d:h?kt:T:v:z:")) != -1)
 
     switch (i) {
 
@@ -116,6 +122,11 @@ int main(int argc, char **argv)
       tag_active = optarg;
       break;
 
+    case 'v': /* variable */
+      if (ftvar_pset(&ftvar, optarg) < 0)
+        fterr_errx(1, "ftvar_pset(%s): failed", optarg);
+      break;
+
     case 'z': /* compress level */
       ftset.z_level = atoi(optarg);
       if ((ftset.z_level < 0) || (ftset.z_level > 9))
@@ -135,7 +146,7 @@ int main(int argc, char **argv)
     fterr_errx(1, "Extra arguments starting with %s.", argv[optind]);
 
   /* read config file */
-  if (fttag_load(&fttag, tag_defs) < 0)
+  if (fttag_load(&fttag, &ftvar, tag_defs) < 0)
     fterr_errx(1, "fttag_load(): failed");
 
   if (!(ftd = fttag_def_find(&fttag, tag_active))) 
@@ -228,6 +239,8 @@ int main(int argc, char **argv)
 
   fttag_free(&fttag);
 
+  ftvar_free(&ftvar);
+
   return 0;
 
 } /* main */
